@@ -256,7 +256,7 @@ public class CKANPublisherServicesImpl extends RemoteServiceServlet implements C
 		String keyPerVocabulary = UtilMethods.concatenateSessionKeyScope("TAGS_VOCABULARY", context); // TODO REMOVE
 
 		List<String> vocabulary = (List<String>) getThreadLocalRequest().getSession().getAttribute(keyPerVocabulary);
-		if(vocabulary != null){
+		if(vocabulary == null){
 			vocabulary = new DiscoverTagsList(context).getTagsVocabulary();
 			getThreadLocalRequest().getSession().setAttribute(keyPerVocabulary, vocabulary);
 		}
